from tkinter import *
from tkinter import messagebox as mb
import os

class XwUniversalError(Exception):
	def __init__(self,message):
		self.message = message
	def __str__(self):
		return f'OH!NO!AN ERROR!{self.message}'

def Input(title,message,passw=0,tip='*'):#pss = 0,noPass;pass = 1,pass]
	global get
	inputBox = Tk()
	inputBox.geometry('200x100')
	inputBox.title(title)
	inputBox.resizable(False,False)
	if passw == 0:#noPass
		label = Label(inputBox,text=message,font=('微软雅黑',17))
		label.place(x=0,y=0)
		def getInput():
			global get
			get = text.get()
			inputBox.after(100,inputBox.destroy())
		text = Entry(inputBox,width=28,font=('微软雅黑',12))
		text.place(x=0,y=30)
		okButton = Button(inputBox,text='确认',width=15,command=getInput)
		okButton.place(x=0,y=70)
		canButton = Button(inputBox,text='取消',width=11,command=quit)
		canButton.place(x=114,y=70)
		inputBox.mainloop()
		return get
	if passw == 1:#Pass
		label = Label(inputBox,text=message,font=('微软雅黑',17))
		label.place(x=0,y=0)
		def getInput():
			global get
			get = text.get()
			inputBox.after(100,inputBox.destroy())
		text = Entry(inputBox,width=28,font=('微软雅黑',12),show=tip)
		text.place(x=0,y=30)
		okButton = Button(inputBox,text='确认',width=15,command=getInput)
		okButton.place(x=0,y=70)
		canButton = Button(inputBox,text='取消',width=11,command=quit)
		canButton.place(x=114,y=70)
		inputBox.mainloop()
		return get
	else:
		inputBox.destroy()
		raise XwUniversalError(f'Unknown Parameter [passw]:{passw}')
q = Input(title='a',message='aaa',passw=0)
print(q)


from tkinter import *
from tkinter import ttk
from tkinter import messagebox as msgbox
from tkinter import font

def FontChoose():
	def Updata_TestLabel():
		try:
			NewFont_Font = FontCombo_Font.get()
			NewFont_Size = FontCombo_Size.get()
			NewFont = font.Font(
				family=NewFont_Font,
				size=int(NewFont_Size),
				weight="bold" if BoldVar.get() else "normal"
			)
		except Exception as e:
			msgbox.showerror('错误',f'错误！{e}')
			exit()
		FontLabel_Test.config(font=NewFont)
	def ApplyNewFont():
		global OutputFont
		try:
			NewFont_Font = FontCombo_Font.get()
			NewFont_Size = FontCombo_Size.get()
			NewFont = font.Font(
				family=NewFont_Font,
				size=int(NewFont_Size),
				weight="bold" if BoldVar.get() else "normal"
			)
		except Exception as e:
			
			msgbox.showerror('错误',f'错误！{e}')
			exit()
		FontLabel_Test.config(font=NewFont)
		FontWindow.after(100,FontWindow.destroy)
		OutputFont = NewFont_Font,NewFont_Size
	FontWindow = Tk()
	FontWindow.title('选择一个字体...')
	FontWindow.geometry('300x150')

	FontWindow.resizable(False,False)
	FontLabel_Font = Label(FontWindow,text='字体:')
	FontLabel_Font.place(x=0,y=0)
	FontLabel_Size = Label(FontWindow,text='字号:')
	FontLabel_Size.place(x=0,y=22)

	FontCombo_Font = ttk.Combobox(FontWindow,width='18')
	FontCombo_Font.place(x=40,y=0)
	FontCombo_Size = ttk.Combobox(FontWindow,width='8')
	FontCombo_Size.place(x=40,y=22)
	Font_Families = sorted(font.families())
	FontCombo_Font.config(values=Font_Families)
	FontCombo_Size.config(values=[8,9,10,11,12,14,16,18,20,22,24])

	BoldVar = BooleanVar()
	FontCheck_Bold = Checkbutton(FontWindow,text='加粗？',variable=BoldVar)
	FontCheck_Bold.place(x=200,y=22)

	FontLabel_Test = Label(FontWindow,text='测试文本 ABCabc 123')
	FontLabel_Test.place(x=0,y=80)

	FontButton_Exp = ttk.Button(FontWindow,text='测试',command=Updata_TestLabel,width=10)
	FontButton_Exp.place(x=0,y=50)
	FontButton_App = ttk.Button(FontWindow,text='应用',command=ApplyNewFont,width=10)
	FontButton_App.place(x=80,y=50)

	FontWindow.mainloop()
	return OutputFont

if __name__ == '__main__':
	a = FontChoose()
	print(a)


from distutils.core import  setup
import setuptools
packages = ['XwsLibrary']# 唯一的包名，自己取名
setup(name='XwsLibrary',
	version='1.1',
	author='XiaoWang',
    description="wow~高级",
    author_email='wzxddzyj1@outlook.com',
    packages=packages, 
    package_dir={'requests': 'requests'},)
